# h5max

A utility package built upon `h5py` for easier data saving and loading.

This package features:
- facilitated saving and loading of sparse matrices using `scipy`.

This package is originally created for large data sets featuring sparse matrices.